@@ -1,4 +1,4 @@
-# Homology modeling by the automodel class
+# Comparative modeling by the automodel class
 from modeller import *
 from modeller.automodel import *    # Load the automodel class
 
@@ -28,4 +28,4 @@ a.loop.starting_model = 1
 a.loop.ending_model   = 2
 a.loop.md_level       = refine.very_fast
 
-a.make()                            # do homology modeling
+a.make()                            # do comparative modeling
